Chromium Code Reviews

Unified Diff: webkit/glue/plugins/webplugin_page_delegate.h

Issue 5998002: Revert "Move the NPAPI files from webkit/glue/plugins to webkit/plugins/npapi" (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « webkit/glue/plugins/webplugin_impl_unittest.cc ('k') | webkit/glue/plugins/webplugin_print_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/plugins/webplugin_page_delegate.h
diff --git a/webkit/plugins/npapi/webplugin_page_delegate.h b/webkit/glue/plugins/webplugin_page_delegate.h
similarity index 86%
rename from webkit/plugins/npapi/webplugin_page_delegate.h
rename to webkit/glue/plugins/webplugin_page_delegate.h
index 15aa73049218946a6734e5b21019d0968ebb9124..d915fdd2aaf2f65ea3770457bc7fddaa2030b837 100644
--- a/webkit/plugins/npapi/webplugin_page_delegate.h
+++ b/webkit/glue/plugins/webplugin_page_delegate.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef WEBKIT_PLUGINS_NPAPI_WEBPLUGIN_PAGE_DELEGATE_
-#define WEBKIT_PLUGINS_NPAPI_WEBPLUGIN_PAGE_DELEGATE_
+#ifndef WEBKIT_GLUE_WEBPLUGIN_PAGE_DELEGATE_
+#define WEBKIT_GLUE_WEBPLUGIN_PAGE_DELEGATE_
#include "gfx/native_widget_types.h"
@@ -14,8 +14,7 @@ namespace WebKit {
class WebCookieJar;
}
-namespace webkit {
-namespace npapi {
+namespace webkit_glue {
class WebPluginDelegate;
struct WebPluginGeometry;
@@ -24,7 +23,7 @@ struct WebPluginGeometry;
class WebPluginPageDelegate {
public:
// This method is called to create a WebPluginDelegate implementation when a
// new plugin is instanced. See CreateWebPluginDelegateHelper
// for a default WebPluginDelegate implementation.
virtual WebPluginDelegate* CreatePluginDelegate(
const FilePath& file_path,
@@ -65,7 +64,6 @@ class WebPluginPageDelegate {
virtual WebKit::WebCookieJar* GetCookieJar() = 0;
};
-} // namespace npapi
-} // namespace webkit
+} // namespace webkit_glue
-#endif // WEBKIT_PLUGINS_NPAPI_WEBPLUGIN_PAGE_DELEGATE_H_
+#endif // WEBKIT_GLUE_WEBPLUGIN_PAGE_DELEGATE_H_
« no previous file with comments | « webkit/glue/plugins/webplugin_impl_unittest.cc ('k') | webkit/glue/plugins/webplugin_print_delegate.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -24,7 +23,7 @@ struct WebPluginGeometry;
public:
// This method is called to create a WebPluginDelegate implementation when a
- // new plugin is instanced. See CreateWebPluginDelegateHelper
+ // new plugin is instanced. See webkit_glue::CreateWebPluginDelegateHelper
// for a default WebPluginDelegate implementation.
virtual WebPluginDelegate* CreatePluginDelegate(